@@ -5,6 +5,7 @@ use crate::types::tag::{Accessor, Tag, TagType};
 
 use std::convert::TryInto;
 use std::fs::{File, OpenOptions};
+use std::io::Write;
 use std::path::Path;
 
 macro_rules! impl_accessor {
@@ -53,19 +54,19 @@ macro_rules! impl_accessor {
 ///
 /// ## Item storage
 ///
-/// `APE` isn't a very strict format. An [ApeItem] only restricted by its name, meaning it can use
+/// `APE` isn't a very strict format. An [`ApeItem`] only restricted by its name, meaning it can use
 /// a normal [`ItemValue`](crate::ItemValue) unlike other formats.
 ///
 /// Pictures are stored as [`ItemValue::Binary`](crate::ItemValue::Binary), and can be converted with
 /// [`Picture::from_ape_bytes`](crate::Picture::from_ape_bytes). For the appropriate item keys, see
-/// [APE_PICTURE_TYPES](crate::ape::APE_PICTURE_TYPES).
+/// [`APE_PICTURE_TYPES`](crate::ape::APE_PICTURE_TYPES).
 ///
 /// ## Conversions
 ///
 /// ### From `Tag`
 ///
 /// When converting pictures, any of type [`PictureType::Undefined`](crate::PictureType::Undefined) will be discarded.
-/// For items, see [ApeItem::new].
+/// For items, see [`ApeItem::new`].
 pub struct ApeTag {
 	/// Whether or not to mark the tag as read only
 	pub read_only: bool,
@@ -134,6 +135,15 @@ impl ApeTag {
 	pub fn write_to(&self, file: &mut File) -> Result<()> {
 		Into::<ApeTagRef>::into(self).write_to(file)
 	}
+
+	/// Dumps the tag to a writer
+	///
+	/// # Errors
+	///
+	/// * [`std::io::Error`]
+	pub fn dump_to<W: Write>(&self, writer: &mut W) -> Result<()> {
+		Into::<ApeTagRef>::into(self).dump_to(writer)
+	}
 }
 
 impl From<ApeTag> for Tag {
@@ -146,13 +156,12 @@ impl From<ApeTag> for Tag {
 		) -> Option<()> {
 			let mut split = content.splitn(2, '/');
 			let current = split.next()?.to_string();
-			tag.insert_item_unchecked(TagItem::new(current_key, ItemValue::Text(current)));
+			tag.items
+				.push(TagItem::new(current_key, ItemValue::Text(current)));
 
 			if let Some(total) = split.next() {
-				tag.insert_item_unchecked(TagItem::new(
-					total_key,
-					ItemValue::Text(total.to_string()),
-				))
+				tag.items
+					.push(TagItem::new(total_key, ItemValue::Text(total.to_string())))
 			}
 
 			Some(())
@@ -177,7 +186,7 @@ impl From<ApeTag> for Tag {
 				{
 					continue
 				},
-				(k, _) => tag.insert_item_unchecked(TagItem::new(k, item.value)),
+				(k, _) => tag.items.push(TagItem::new(k, item.value)),
 			}
 		}
 
@@ -218,6 +227,13 @@ impl<'a> ApeTagRef<'a> {
 	pub(crate) fn write_to(&mut self, file: &mut File) -> Result<()> {
 		super::write::write_to(file, self)
 	}
+
+	pub(crate) fn dump_to<W: Write>(&mut self, writer: &mut W) -> Result<()> {
+		let temp = super::write::create_ape_tag(self)?;
+		writer.write_all(&*temp)?;
+
+		Ok(())
+	}
 }
 
 impl<'a> Into<ApeTagRef<'a>> for &'a Tag {
@@ -250,7 +266,7 @@ mod tests {
 	use crate::{ItemValue, Tag, TagType};
 
 	use crate::ape::tag::read_ape_header;
-	use std::io::{Cursor, Read};
+	use std::io::Cursor;
 
 	#[test]
 	fn parse_ape() {
@@ -300,12 +316,7 @@ mod tests {
 		expected_tag.insert(track_number_item);
 		expected_tag.insert(genre_item);
 
-		let mut tag = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.apev2")
-			.unwrap()
-			.read_to_end(&mut tag)
-			.unwrap();
-
+		let tag = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.apev2");
 		let mut reader = Cursor::new(tag);
 
 		let header = read_ape_header(&mut reader, false).unwrap();
@@ -319,13 +330,29 @@ mod tests {
 	}
 
 	#[test]
-	fn ape_to_tag() {
-		let mut tag_bytes = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.apev2")
-			.unwrap()
-			.read_to_end(&mut tag_bytes)
-			.unwrap();
+	fn ape_re_read() {
+		let tag_bytes = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.apev2");
+		let mut reader = Cursor::new(tag_bytes);
 
+		let header = read_ape_header(&mut reader, false).unwrap();
+		let parsed_tag = crate::ape::tag::read::read_ape_tag(&mut reader, header).unwrap();
+
+		let mut writer = Vec::new();
+		parsed_tag.dump_to(&mut writer).unwrap();
+
+		// Remove the APE preamble
+		let mut temp_reader = Cursor::new(&writer[8..]);
+
+		let temp_header = read_ape_header(&mut temp_reader, false).unwrap();
+		let temp_parsed_tag =
+			crate::ape::tag::read::read_ape_tag(&mut temp_reader, temp_header).unwrap();
+
+		assert_eq!(parsed_tag, temp_parsed_tag);
+	}
+
+	#[test]
+	fn ape_to_tag() {
+		let tag_bytes = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.apev2");
 		let mut reader = Cursor::new(tag_bytes);
 
 		let header = read_ape_header(&mut reader, false).unwrap();
