@@ -12,6 +12,7 @@ use crate::types::tag::{Accessor, Tag, TagType};
 
 use std::convert::TryInto;
 use std::fs::{File, OpenOptions};
+use std::io::Write;
 use std::path::Path;
 
 macro_rules! impl_accessor {
@@ -282,7 +283,18 @@ impl Id3v2Tag {
 	/// * Attempting to write the tag to a format that does not support it
 	/// * Attempting to write an encrypted frame without a valid method symbol or data length indicator
 	pub fn write_to(&self, file: &mut File) -> Result<()> {
-		Into::<Id3v2TagRef>::into(self).write_to(file)
+		Id3v2TagRef::new(self.flags, self.frames.iter().filter_map(Frame::as_opt_ref))
+			.write_to(file)
+	}
+
+	/// Dumps the tag to a writer
+	///
+	/// # Errors
+	///
+	/// * [`std::io::Error`]
+	pub fn dump_to<W: Write>(&self, writer: &mut W) -> Result<()> {
+		Id3v2TagRef::new(self.flags, self.frames.iter().filter_map(Frame::as_opt_ref))
+			.dump_to(writer)
 	}
 }
 
@@ -305,13 +317,12 @@ impl From<Id3v2Tag> for Tag {
 		) -> Option<()> {
 			let mut split = content.splitn(2, &['\0', '/'][..]);
 			let current = split.next()?.to_string();
-			tag.insert_item_unchecked(TagItem::new(current_key, ItemValue::Text(current)));
+			tag.items
+				.push(TagItem::new(current_key, ItemValue::Text(current)));
 
 			if let Some(total) = split.next() {
-				tag.insert_item_unchecked(TagItem::new(
-					total_key,
-					ItemValue::Text(total.to_string()),
-				))
+				tag.items
+					.push(TagItem::new(total_key, ItemValue::Text(total.to_string())))
 			}
 
 			Some(())
@@ -355,7 +366,7 @@ impl From<Id3v2Tag> for Tag {
 				FrameValue::Binary(binary) => ItemValue::Binary(binary),
 			};
 
-			tag.insert_item_unchecked(TagItem::new(item_key, item_value))
+			tag.items.push(TagItem::new(item_key, item_value));
 		}
 
 		tag
@@ -375,7 +386,7 @@ impl From<Tag> for Id3v2Tag {
 				Err(_) => continue,
 			};
 
-			id3v2_tag.frames.push(frame);
+			id3v2_tag.insert(frame);
 		}
 
 		for picture in input.pictures {
@@ -393,47 +404,55 @@ impl From<Tag> for Id3v2Tag {
 	}
 }
 
-pub(crate) struct Id3v2TagRef<'a> {
+pub(crate) struct Id3v2TagRef<'a, I: Iterator<Item = FrameRef<'a>> + 'a> {
 	pub(crate) flags: Id3v2TagFlags,
-	pub(crate) frames: Box<dyn Iterator<Item = FrameRef<'a>> + 'a>,
+	pub(crate) frames: I,
 }
 
-impl<'a> Id3v2TagRef<'a> {
+// Create an iterator of FrameRef from a Tag's items for Id3v2TagRef::new
+pub(crate) fn tag_frames(tag: &Tag) -> impl Iterator<Item = FrameRef<'_>> + '_ {
+	tag.items()
+		.iter()
+		.map(TryInto::<FrameRef>::try_into)
+		.filter_map(Result::ok)
+}
+
+impl<'a, I: Iterator<Item = FrameRef<'a>> + 'a> Id3v2TagRef<'a, I> {
+	pub(crate) fn new(flags: Id3v2TagFlags, frames: I) -> Self {
+		Self { flags, frames }
+	}
+}
+
+impl<'a, I: Iterator<Item = FrameRef<'a>> + 'a> Id3v2TagRef<'a, I> {
 	pub(crate) fn write_to(&mut self, file: &mut File) -> Result<()> {
 		super::write::write_id3v2(file, self)
 	}
-}
 
-impl<'a> Into<Id3v2TagRef<'a>> for &'a Tag {
-	fn into(self) -> Id3v2TagRef<'a> {
-		Id3v2TagRef {
-			flags: Id3v2TagFlags::default(),
-			frames: Box::new(
-				self.items()
-					.iter()
-					.map(TryInto::<FrameRef>::try_into)
-					.filter_map(Result::ok),
-			),
-		}
-	}
-}
+	pub(crate) fn dump_to<W: Write>(&mut self, writer: &mut W) -> Result<()> {
+		let temp = super::write::create_tag(self)?;
+		writer.write_all(&*temp)?;
 
-impl<'a> Into<Id3v2TagRef<'a>> for &'a Id3v2Tag {
-	fn into(self) -> Id3v2TagRef<'a> {
-		Id3v2TagRef {
-			flags: self.flags,
-			frames: Box::new(self.frames.iter().filter_map(Frame::as_opt_ref)),
-		}
+		Ok(())
 	}
 }
 
 #[cfg(test)]
 mod tests {
-	use crate::id3::v2::{Frame, FrameFlags, FrameValue, Id3v2Tag, LanguageFrame, TextEncoding};
-	use crate::{Tag, TagType};
+	use crate::id3::v2::{
+		read_id3v2_header, Frame, FrameFlags, FrameID, FrameValue, Id3v2Tag, Id3v2Version,
+		LanguageFrame, TextEncoding,
+	};
+	use crate::tag_utils::test_utils::read_path;
+	use crate::{MimeType, Picture, PictureType, Tag, TagType};
 
-	use crate::id3::v2::read_id3v2_header;
-	use std::io::Read;
+	fn read_tag(path: &str) -> Id3v2Tag {
+		let tag_bytes = crate::tag_utils::test_utils::read_path(path);
+
+		let mut reader = std::io::Cursor::new(&tag_bytes[..]);
+
+		let header = read_id3v2_header(&mut reader).unwrap();
+		crate::id3::v2::read::parse_id3v2(&mut reader, header).unwrap()
+	}
 
 	#[test]
 	fn parse_id3v2() {
@@ -528,32 +547,29 @@ mod tests {
 			.unwrap(),
 		);
 
-		let mut tag = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.id3v2")
-			.unwrap()
-			.read_to_end(&mut tag)
-			.unwrap();
-
-		let mut reader = std::io::Cursor::new(&tag[..]);
-
-		let header = read_id3v2_header(&mut reader).unwrap();
-		let parsed_tag = crate::id3::v2::read::parse_id3v2(&mut reader, header).unwrap();
+		let parsed_tag = read_tag("tests/tags/assets/id3v2/test.id3v24");
 
 		assert_eq!(expected_tag, parsed_tag);
 	}
 
+	#[test]
+	fn id3v2_re_read() {
+		let parsed_tag = read_tag("tests/tags/assets/id3v2/test.id3v24");
+
+		let mut writer = Vec::new();
+		parsed_tag.dump_to(&mut writer).unwrap();
+
+		let temp_reader = &mut &*writer;
+
+		let temp_header = read_id3v2_header(temp_reader).unwrap();
+		let temp_parsed_tag = crate::id3::v2::read::parse_id3v2(temp_reader, temp_header).unwrap();
+
+		assert_eq!(parsed_tag, temp_parsed_tag);
+	}
+
 	#[test]
 	fn id3v2_to_tag() {
-		let mut tag_bytes = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.id3v2")
-			.unwrap()
-			.read_to_end(&mut tag_bytes)
-			.unwrap();
-
-		let mut reader = std::io::Cursor::new(&tag_bytes[..]);
-
-		let header = read_id3v2_header(&mut reader).unwrap();
-		let id3v2 = crate::id3::v2::read::parse_id3v2(&mut reader, header).unwrap();
+		let id3v2 = read_tag("tests/tags/assets/id3v2/test.id3v24");
 
 		let tag: Tag = id3v2.into();
 
@@ -600,4 +616,116 @@ mod tests {
 		verify_frame(&id3v2_tag, "TRCK", "1");
 		verify_frame(&id3v2_tag, "TCON", "Classical");
 	}
+
+	#[allow(clippy::field_reassign_with_default)]
+	fn create_full_test_tag(version: Id3v2Version) -> Id3v2Tag {
+		let mut tag = Id3v2Tag::default();
+		tag.original_version = version;
+
+		let encoding = TextEncoding::UTF16;
+		let flags = FrameFlags::default();
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TIT2")),
+			value: FrameValue::Text {
+				encoding,
+				value: String::from("TempleOS Hymn Risen (Remix)"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TPE1")),
+			value: FrameValue::Text {
+				encoding,
+				value: String::from("Dave Eddy"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TRCK")),
+			value: FrameValue::Text {
+				encoding: TextEncoding::Latin1,
+				value: String::from("1"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TALB")),
+			value: FrameValue::Text {
+				encoding,
+				value: String::from("Summer"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TDRC")),
+			value: FrameValue::Text {
+				encoding,
+				value: String::from("2017"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TCON")),
+			value: FrameValue::Text {
+				encoding,
+				value: String::from("Electronic"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("TLEN")),
+			value: FrameValue::Text {
+				encoding: TextEncoding::UTF16,
+				value: String::from("213017"),
+			},
+			flags,
+		});
+
+		tag.insert(Frame {
+			id: FrameID::Valid(String::from("APIC")),
+			value: FrameValue::Picture {
+				encoding: TextEncoding::Latin1,
+				picture: Picture {
+					pic_type: PictureType::CoverFront,
+					mime_type: MimeType::Png,
+					description: None,
+					data: read_path("tests/tags/assets/id3v2/test_full_cover.png").into(),
+				},
+			},
+			flags,
+		});
+
+		tag
+	}
+
+	#[test]
+	fn id3v24_full() {
+		let tag = create_full_test_tag(Id3v2Version::V4);
+		let parsed_tag = read_tag("tests/tags/assets/id3v2/test_full.id3v24");
+
+		assert_eq!(tag, parsed_tag);
+	}
+
+	#[test]
+	fn id3v23_full() {
+		let tag = create_full_test_tag(Id3v2Version::V3);
+		let parsed_tag = read_tag("tests/tags/assets/id3v2/test_full.id3v23");
+
+		assert_eq!(tag, parsed_tag);
+	}
+
+	#[test]
+	fn id3v22_full() {
+		let tag = create_full_test_tag(Id3v2Version::V2);
+		let parsed_tag = read_tag("tests/tags/assets/id3v2/test_full.id3v22");
+
+		assert_eq!(tag, parsed_tag);
+	}
 }
