@@ -1,5 +1,5 @@
 #[cfg(feature = "aiff_text_chunks")]
-use super::tag::AiffTextChunks;
+use super::tag::{AiffTextChunks, Comment};
 use super::AiffFile;
 use crate::error::{LoftyError, Result};
 #[cfg(feature = "id3v2")]
@@ -9,7 +9,7 @@ use crate::types::properties::FileProperties;
 
 use std::io::{Read, Seek, SeekFrom};
 
-use byteorder::BigEndian;
+use byteorder::{BigEndian, ReadBytesExt};
 
 pub(in crate::iff) fn verify_aiff<R>(data: &mut R) -> Result<()>
 where
@@ -36,6 +36,11 @@ where
 
 	#[cfg(feature = "aiff_text_chunks")]
 	let mut text_chunks = AiffTextChunks::default();
+	#[cfg(feature = "aiff_text_chunks")]
+	let mut annotations = Vec::new();
+	#[cfg(feature = "aiff_text_chunks")]
+	let mut comments = Vec::new();
+
 	#[cfg(feature = "id3v2")]
 	let mut id3v2_tag: Option<Id3v2Tag> = None;
 
@@ -45,42 +50,71 @@ where
 		match &chunks.fourcc {
 			#[cfg(feature = "id3v2")]
 			b"ID3 " | b"id3 " => id3v2_tag = Some(chunks.id3_chunk(data)?),
-			b"COMM" if read_properties => {
-				if comm.is_none() {
-					if chunks.size < 18 {
-						return Err(LoftyError::Aiff(
-							"File has an invalid \"COMM\" chunk size (< 18)",
-						));
-					}
-
-					comm = Some(chunks.content(data)?);
+			b"COMM" if read_properties && comm.is_none() => {
+				if chunks.size < 18 {
+					return Err(LoftyError::Aiff(
+						"File has an invalid \"COMM\" chunk size (< 18)",
+					));
 				}
+
+				comm = Some(chunks.content(data)?);
+				chunks.correct_position(data)?;
 			},
 			b"SSND" if read_properties => {
 				stream_len = chunks.size;
-				data.seek(SeekFrom::Current(i64::from(chunks.size)))?;
+				chunks.skip(data)?;
 			},
 			#[cfg(feature = "aiff_text_chunks")]
-			b"NAME" => {
-				let value = String::from_utf8(chunks.content(data)?)?;
-				text_chunks.name = Some(value);
+			b"ANNO" => {
+				annotations.push(chunks.read_pstring(data, None)?);
+			},
+			// These four chunks are expected to appear at most once per file,
+			// so there's no need to replace anything we already read
+			#[cfg(feature = "aiff_text_chunks")]
+			b"COMT" if comments.is_empty() => {
+				let num_comments = data.read_u16::<BigEndian>()?;
+
+				for _ in 0..num_comments {
+					let timestamp = data.read_u32::<BigEndian>()?;
+					let marker_id = data.read_u16::<BigEndian>()?;
+					let size = data.read_u16::<BigEndian>()?;
+
+					let text = chunks.read_pstring(data, Some(size as usize))?;
+
+					comments.push(Comment {
+						timestamp,
+						marker_id,
+						text,
+					})
+				}
+
+				chunks.correct_position(data)?;
 			},
 			#[cfg(feature = "aiff_text_chunks")]
-			b"AUTH" => {
-				let value = String::from_utf8(chunks.content(data)?)?;
-				text_chunks.author = Some(value);
+			b"NAME" if text_chunks.name.is_none() => {
+				text_chunks.name = Some(chunks.read_pstring(data, None)?);
 			},
 			#[cfg(feature = "aiff_text_chunks")]
-			b"(c) " => {
-				let value = String::from_utf8(chunks.content(data)?)?;
-				text_chunks.copyright = Some(value);
+			b"AUTH" if text_chunks.author.is_none() => {
+				text_chunks.author = Some(chunks.read_pstring(data, None)?);
 			},
-			_ => {
-				data.seek(SeekFrom::Current(i64::from(chunks.size)))?;
+			#[cfg(feature = "aiff_text_chunks")]
+			b"(c) " if text_chunks.copyright.is_none() => {
+				text_chunks.copyright = Some(chunks.read_pstring(data, None)?);
 			},
+			_ => chunks.skip(data)?,
+		}
+	}
+
+	#[cfg(feature = "aiff_text_chunks")]
+	{
+		if !annotations.is_empty() {
+			text_chunks.annotations = Some(annotations);
 		}
 
-		chunks.correct_position(data)?;
+		if !comments.is_empty() {
+			text_chunks.comments = Some(comments);
+		}
 	}
 
 	let properties = if read_properties {
@@ -109,6 +143,8 @@ where
 				name: None,
 				author: None,
 				copyright: None,
+				annotations: None,
+				comments: None,
 			} => None,
 			_ => Some(text_chunks),
 		},
