@@ -1,8 +1,12 @@
 use crate::error::{LoftyError, Result};
 #[cfg(feature = "id3v2")]
-use crate::id3::v2::tag::Id3v2TagRef;
+use crate::id3::v2::{
+	tag::{tag_frames, Id3v2TagRef},
+	Id3v2TagFlags,
+};
 #[cfg(feature = "aiff_text_chunks")]
 use crate::iff::aiff::tag::AiffTextChunksRef;
+use crate::types::item::ItemKey;
 #[allow(unused_imports)]
 use crate::types::tag::{Tag, TagType};
 
@@ -12,9 +16,16 @@ use std::fs::File;
 pub(crate) fn write_to(data: &mut File, tag: &Tag) -> Result<()> {
 	match tag.tag_type() {
 		#[cfg(feature = "aiff_text_chunks")]
-		TagType::AiffText => Into::<AiffTextChunksRef>::into(tag).write_to(data),
+		TagType::AiffText => AiffTextChunksRef::new(
+			tag.get_string(&ItemKey::TrackTitle),
+			tag.get_string(&ItemKey::TrackArtist),
+			tag.get_string(&ItemKey::CopyrightMessage),
+			Some(tag.get_texts(&ItemKey::Comment)),
+			None,
+		)
+		.write_to(data),
 		#[cfg(feature = "id3v2")]
-		TagType::Id3v2 => Into::<Id3v2TagRef>::into(tag).write_to(data),
+		TagType::Id3v2 => Id3v2TagRef::new(Id3v2TagFlags::default(), tag_frames(tag)).write_to(data),
 		_ => Err(LoftyError::UnsupportedTag),
 	}
 }
