@@ -1,6 +1,9 @@
 use crate::error::{LoftyError, Result};
 #[cfg(feature = "id3v2")]
-use crate::id3::v2::tag::Id3v2TagRef;
+use crate::id3::v2::{
+	tag::{tag_frames, Id3v2TagRef},
+	Id3v2TagFlags,
+};
 #[cfg(feature = "riff_info_list")]
 use crate::iff::wav::tag::RiffInfoListRef;
 #[allow(unused_imports)]
@@ -14,7 +17,7 @@ pub(crate) fn write_to(data: &mut File, tag: &Tag) -> Result<()> {
 		#[cfg(feature = "riff_info_list")]
 		TagType::RiffInfo => Into::<RiffInfoListRef>::into(tag).write_to(data),
 		#[cfg(feature = "id3v2")]
-		TagType::Id3v2 => Into::<Id3v2TagRef>::into(tag).write_to(data),
+		TagType::Id3v2 => Id3v2TagRef::new(Id3v2TagFlags::default(), tag_frames(tag)).write_to(data),
 		_ => Err(LoftyError::UnsupportedTag),
 	}
 }
