@@ -1,13 +1,14 @@
 use super::header::{verify_frame_sync, Header, XingHeader};
 use super::{Mp3File, Mp3Properties};
 use crate::ape::constants::APE_PREAMBLE;
+#[cfg(feature = "ape")]
 use crate::ape::tag::read::read_ape_tag;
 use crate::ape::tag::read_ape_header;
 use crate::error::{LoftyError, Result};
 #[cfg(feature = "id3v2")]
 use crate::id3::v2::read::parse_id3v2;
 use crate::id3::v2::read_id3v2_header;
-use crate::id3::{find_id3v1, find_lyrics3v2};
+use crate::id3::{find_id3v1, find_lyrics3v2, ID3FindResults};
 
 use std::io::{Read, Seek, SeekFrom};
 
@@ -67,7 +68,7 @@ where
 					#[cfg(not(feature = "ape"))]
 					{
 						let size = ape_header.size;
-						data.seek(SeekFrom::Current(size as i64))?;
+						reader.seek(SeekFrom::Current(size as i64))?;
 					}
 
 					#[cfg(feature = "ape")]
@@ -94,10 +95,10 @@ where
 	}
 
 	#[allow(unused_variables)]
-	let (found_id3v1, id3v1) = find_id3v1(reader, true)?;
+	let ID3FindResults(header, id3v1) = find_id3v1(reader, true)?;
 
 	#[cfg(feature = "id3v1")]
-	if found_id3v1 {
+	if header.is_some() {
 		file.id3v1_tag = id3v1;
 	}
 
@@ -131,6 +132,11 @@ where
 		}
 
 		let first_frame_header = first_frame_header.unwrap();
+
+		if first_frame_header.sample_rate == 0 {
+			return Err(LoftyError::Mp3("Sample rate is 0"));
+		}
+
 		let first_frame_offset = file.first_frame_offset.unwrap();
 
 		let file_length = reader.seek(SeekFrom::End(0))?;
