@@ -11,6 +11,7 @@ use atom::{Atom, AtomData, AtomDataRef, AtomIdentRef, AtomRef};
 
 use std::convert::TryInto;
 use std::fs::{File, OpenOptions};
+use std::io::Write;
 use std::path::Path;
 
 const ARTIST: AtomIdent = AtomIdent::Fourcc(*b"\xa9ART");
@@ -59,16 +60,16 @@ macro_rules! impl_accessor {
 /// ## Pictures
 ///
 /// Unlike other formats, ilst does not store a [`PictureType`]. All pictures will have
-/// [PictureType::Other].
+/// [`PictureType::Other`].
 ///
 /// ## Conversions
 ///
 /// ### To `Tag`
 ///
-/// When converting to [`Tag`], only atoms with a value of [AtomData::UTF8] and [AtomData::UTF16], as
+/// When converting to [`Tag`], only atoms with a value of [`AtomData::UTF8`] and [`AtomData::UTF16`], as
 /// well as pictures, will be preserved.
 ///
-/// Do note, all pictures will be [PictureType::Other](crate::PictureType::Other)
+/// Do note, all pictures will be [`PictureType::Other`](crate::PictureType::Other)
 ///
 /// ### From `Tag`
 ///
@@ -197,6 +198,18 @@ impl Ilst {
 	pub fn write_to(&self, file: &mut File) -> Result<()> {
 		Into::<IlstRef>::into(self).write_to(file)
 	}
+
+	/// Dumps the tag to a writer
+	///
+	/// This will only write the ilst atom, it will not create a usable
+	/// file.
+	///
+	/// # Errors
+	///
+	/// * [`std::io::Error`]
+	pub fn dump_to<W: Write>(&self, writer: &mut W) -> Result<()> {
+		Into::<IlstRef>::into(self).dump_to(writer)
+	}
 }
 
 impl From<Ilst> for Tag {
@@ -337,6 +350,13 @@ impl<'a> IlstRef<'a> {
 	pub(crate) fn write_to(&mut self, file: &mut File) -> Result<()> {
 		write::write_to(file, self)
 	}
+
+	pub(crate) fn dump_to<W: Write>(&mut self, writer: &mut W) -> Result<()> {
+		let temp = write::build_ilst(&mut self.atoms)?;
+		writer.write_all(&*temp)?;
+
+		Ok(())
+	}
 }
 
 impl<'a> Into<IlstRef<'a>> for &'a Ilst {
@@ -398,8 +418,6 @@ mod tests {
 	use crate::mp4::{Atom, AtomData, AtomIdent, Ilst};
 	use crate::{ItemKey, Tag, TagType};
 
-	use std::io::Read;
-
 	#[test]
 	fn parse_ilst() {
 		let mut expected_tag = Ilst::default();
@@ -454,24 +472,31 @@ mod tests {
 			AtomData::UTF8(String::from("Foo title")),
 		));
 
-		let mut tag = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.ilst")
-			.unwrap()
-			.read_to_end(&mut tag)
-			.unwrap();
+		let tag = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.ilst");
 
 		let parsed_tag = super::read::parse_ilst(&mut &tag[..], tag.len() as u64).unwrap();
 
 		assert_eq!(expected_tag, parsed_tag);
 	}
 
+	#[test]
+	fn ilst_re_read() {
+		let tag = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.ilst");
+		let parsed_tag = super::read::parse_ilst(&mut &tag[..], tag.len() as u64).unwrap();
+
+		let mut writer = Vec::new();
+		parsed_tag.dump_to(&mut writer).unwrap();
+
+		// Remove the ilst identifier and size
+		let temp_parsed_tag =
+			super::read::parse_ilst(&mut &writer[8..], (writer.len() - 8) as u64).unwrap();
+
+		assert_eq!(parsed_tag, temp_parsed_tag);
+	}
+
 	#[test]
 	fn ilst_to_tag() {
-		let mut tag_bytes = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.ilst")
-			.unwrap()
-			.read_to_end(&mut tag_bytes)
-			.unwrap();
+		let tag_bytes = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.ilst");
 
 		let ilst = super::read::parse_ilst(&mut &tag_bytes[..], tag_bytes.len() as u64).unwrap();
 
