@@ -7,6 +7,7 @@ use crate::types::picture::{Picture, PictureInformation, PictureType};
 use crate::types::tag::{Accessor, Tag, TagType};
 
 use std::fs::{File, OpenOptions};
+use std::io::{Cursor, Write};
 use std::path::Path;
 
 macro_rules! impl_accessor {
@@ -152,19 +153,32 @@ impl VorbisComments {
 	pub fn write_to(&self, file: &mut File) -> Result<()> {
 		Into::<VorbisCommentsRef>::into(self).write_to(file)
 	}
+
+	/// Dumps the tag to a writer
+	///
+	/// This does not include a vendor string, and will thus
+	/// not create a usable file.
+	///
+	/// # Errors
+	///
+	/// * [`PictureInformation::from_picture`]
+	/// * [`std::io::Error`]
+	pub fn dump_to<W: Write>(&self, writer: &mut W) -> Result<()> {
+		Into::<VorbisCommentsRef>::into(self).dump_to(writer)
+	}
 }
 
 impl From<VorbisComments> for Tag {
 	fn from(input: VorbisComments) -> Self {
 		let mut tag = Tag::new(TagType::VorbisComments);
 
-		tag.insert_item_unchecked(TagItem::new(
+		tag.items.push(TagItem::new(
 			ItemKey::EncoderSoftware,
 			ItemValue::Text(input.vendor),
 		));
 
 		for (k, v) in input.items {
-			tag.insert_item_unchecked(TagItem::new(
+			tag.items.push(TagItem::new(
 				ItemKey::from_key(TagType::VorbisComments, &k),
 				ItemValue::Text(v),
 			));
@@ -179,11 +193,15 @@ impl From<VorbisComments> for Tag {
 }
 
 impl From<Tag> for VorbisComments {
-	fn from(input: Tag) -> Self {
+	fn from(mut input: Tag) -> Self {
 		let mut vorbis_comments = Self::default();
 
-		if let Some(vendor) = input.get_string(&ItemKey::EncoderSoftware) {
-			vorbis_comments.vendor = vendor.to_string()
+		if let Some(TagItem {
+			item_value: ItemValue::Text(val),
+			..
+		}) = input.take(&ItemKey::EncoderSoftware).next()
+		{
+			vorbis_comments.vendor = val;
 		}
 
 		for item in input.items {
@@ -234,6 +252,14 @@ impl<'a> VorbisCommentsRef<'a> {
 			_ => Err(LoftyError::UnsupportedTag),
 		}
 	}
+
+	pub(crate) fn dump_to<W: Write>(&mut self, writer: &mut W) -> Result<()> {
+		let mut temp = Cursor::new(Vec::new());
+		super::write::create_pages(self, &mut temp)?;
+
+		writer.write_all(temp.get_ref())?;
+		Ok(())
+	}
 }
 
 impl<'a> Into<VorbisCommentsRef<'a>> for &'a VorbisComments {
@@ -251,10 +277,14 @@ impl<'a> Into<VorbisCommentsRef<'a>> for &'a Tag {
 		let vendor = self.get_string(&ItemKey::EncoderSoftware).unwrap_or("");
 
 		let items = self.items.iter().filter_map(|i| match i.value() {
-			ItemValue::Text(val) | ItemValue::Locator(val) => i
-				.key()
-				.map_key(TagType::VorbisComments, true)
-				.map(|key| (key, val)),
+			ItemValue::Text(val) | ItemValue::Locator(val)
+				// Already got the vendor above
+				if i.key() != &ItemKey::EncoderSoftware =>
+			{
+				i.key()
+					.map_key(TagType::VorbisComments, true)
+					.map(|key| (key, val))
+			},
 			_ => None,
 		});
 
@@ -277,6 +307,14 @@ mod tests {
 
 	use std::io::Read;
 
+	fn read_tag(tag: &[u8]) -> VorbisComments {
+		let mut reader = std::io::Cursor::new(tag);
+		let mut parsed_tag = VorbisComments::default();
+
+		crate::ogg::read::read_comments(&mut reader, &mut parsed_tag).unwrap();
+		parsed_tag
+	}
+
 	#[test]
 	fn parse_vorbis_comments() {
 		let mut expected_tag = VorbisComments::default();
@@ -291,20 +329,28 @@ mod tests {
 		expected_tag.insert_item(String::from("TITLE"), String::from("Foo title"), false);
 		expected_tag.insert_item(String::from("TRACKNUMBER"), String::from("1"), false);
 
-		let mut tag = Vec::new();
-		std::fs::File::open("tests/tags/assets/test.vorbis")
-			.unwrap()
-			.read_to_end(&mut tag)
-			.unwrap();
-
-		let mut reader = std::io::Cursor::new(&tag[..]);
-		let mut parsed_tag = VorbisComments::default();
-
-		crate::ogg::read::read_comments(&mut reader, &mut parsed_tag).unwrap();
+		let file_cont = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.vorbis");
+		let parsed_tag = read_tag(&*file_cont);
 
 		assert_eq!(expected_tag, parsed_tag);
 	}
 
+	#[test]
+	fn vorbis_comments_re_read() {
+		let file_cont = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.vorbis");
+		let mut parsed_tag = read_tag(&*file_cont);
+
+		// Create a zero-size vendor for comparison
+		parsed_tag.vendor = String::new();
+
+		let mut writer = vec![0, 0, 0, 0];
+		parsed_tag.dump_to(&mut writer).unwrap();
+
+		let temp_parsed_tag = read_tag(&*writer);
+
+		assert_eq!(parsed_tag, temp_parsed_tag);
+	}
+
 	#[test]
 	fn vorbis_comments_to_tag() {
 		let mut tag_bytes = Vec::new();
