@@ -1,7 +1,6 @@
-use super::{page_from_packet, verify_signature};
+use super::verify_signature;
 use crate::error::{LoftyError, Result};
-use crate::ogg::constants::OPUSTAGS;
-use crate::ogg::constants::VORBIS_COMMENT_HEAD;
+use crate::ogg::constants::{OPUSTAGS, VORBIS_COMMENT_HEAD};
 use crate::ogg::tag::VorbisCommentsRef;
 use crate::types::picture::PictureInformation;
 use crate::types::tag::{Tag, TagType};
@@ -47,7 +46,10 @@ pub(crate) fn create_comments(
 }
 
 #[cfg(feature = "vorbis_comments")]
-fn create_pages(tag: &mut VorbisCommentsRef, writer: &mut Cursor<Vec<u8>>) -> Result<Vec<Page>> {
+pub(super) fn create_pages(
+	tag: &mut VorbisCommentsRef,
+	writer: &mut Cursor<Vec<u8>>,
+) -> Result<Vec<Page>> {
 	const PICTURE_KEY: &str = "METADATA_BLOCK_PICTURE=";
 
 	let item_count_pos = writer.seek(SeekFrom::Current(0))?;
@@ -77,7 +79,9 @@ fn create_pages(tag: &mut VorbisCommentsRef, writer: &mut Cursor<Vec<u8>>) -> Re
 	writer.write_u32::<LittleEndian>(count)?;
 	writer.seek(SeekFrom::Start(packet_end))?;
 
-	page_from_packet(writer.get_mut())
+	// Stream serial is retrieved later
+	// Checksum is calculated later
+	Ok(ogg_pager::paginate(writer.get_ref(), 0, 0, 0))
 }
 
 #[cfg(feature = "vorbis_comments")]
@@ -93,7 +97,7 @@ pub(super) fn write(data: &mut File, tag: &mut VorbisCommentsRef, sig: &[u8]) ->
 	verify_signature(&first_md_page, sig)?;
 
 	// Retain the file's vendor string
-	let md_reader = &mut &first_md_page.content[sig.len()..];
+	let md_reader = &mut &first_md_page.content()[sig.len()..];
 
 	let vendor_len = md_reader.read_u32::<LittleEndian>()?;
 	let mut vendor = vec![0; vendor_len as usize];
@@ -112,7 +116,7 @@ pub(super) fn write(data: &mut File, tag: &mut VorbisCommentsRef, sig: &[u8]) ->
 			super::vorbis::write::write_to(
 				data,
 				&mut writer,
-				first_md_page.content,
+				first_md_page.take_content(),
 				ser,
 				&mut pages,
 			)?;
