@@ -65,9 +65,10 @@ gen_map!(
 	#[cfg(feature = "aiff_text_chunks")]
 	AIFF_TEXT_MAP;
 
-	"NAME" => TrackTitle,
-	"AUTH" => TrackArtist,
-	"(c) " => CopyrightMessage
+	"NAME" 			=> TrackTitle,
+	"AUTH" 			=> TrackArtist,
+	"(c) " 			=> CopyrightMessage,
+	"COMM" | "AUTH" => Comment
 );
 
 gen_map!(
@@ -355,7 +356,7 @@ macro_rules! gen_item_keys {
 		}
 
 		impl ItemKey {
-			/// Map a format specific key to an ItemKey
+			/// Map a format specific key to an `ItemKey`
 			///
 			/// NOTE: If used with ID3v2, this will only check against the ID3v2.4 keys.
 			/// If you wish to use a V2 or V3 key, see [`upgrade_v2`](crate::id3::v2::upgrade_v2) and [`upgrade_v3`](crate::id3::v2::upgrade_v3)
@@ -548,6 +549,32 @@ pub enum ItemValue {
 	Binary(Vec<u8>),
 }
 
+impl ItemValue {
+	/// Returns the value if the variant is `Text`
+	pub fn text(&self) -> Option<&str> {
+		match self {
+			Self::Text(ref text) => Some(text),
+			_ => None,
+		}
+	}
+
+	/// Returns the value if the variant is `Locator`
+	pub fn locator(&self) -> Option<&str> {
+		match self {
+			Self::Locator(ref locator) => Some(locator),
+			_ => None,
+		}
+	}
+
+	/// Returns the value if the variant is `Binary`
+	pub fn binary(&self) -> Option<&[u8]> {
+		match self {
+			Self::Binary(ref bin) => Some(bin),
+			_ => None,
+		}
+	}
+}
+
 pub(crate) enum ItemValueRef<'a> {
 	Text(&'a str),
 	Locator(&'a str),
@@ -608,14 +635,14 @@ impl TagItem {
 		&self.item_value
 	}
 
-	pub(crate) fn re_map(&self, tag_type: TagType) -> Option<()> {
+	pub(crate) fn re_map(&self, tag_type: TagType) -> bool {
 		#[cfg(feature = "id3v1")]
 		if tag_type == TagType::Id3v1 {
 			use crate::id3::v1::constants::VALID_ITEMKEYS;
 
-			return VALID_ITEMKEYS.contains(&self.item_key).then(|| ());
+			return VALID_ITEMKEYS.contains(&self.item_key);
 		}
 
-		self.item_key.map_key(tag_type, false).is_some().then(|| ())
+		self.item_key.map_key(tag_type, false).is_some()
 	}
 }
